Crate kcr_hyperspike_io

Crate kcr_hyperspike_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the hyperspike.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

hyperspike.io/v1

  • Valkey

Modules

v1